@@ -358,7 +358,7 @@ def do_force(packages):
             # the download archive, if there is any there.
             #
             lscmd  = "/bin/ls " + archives
-            lscmd += " | egrep '^" + pkg + "_' | sort | tail -1"
+            lscmd += " | egrep '^" + pkg + "_' | sort | tail -n -1"
             matches = perform.execute(lscmd, pipe=True)
             debpkg = matches.readline().strip()
             #
@@ -1434,6 +1434,17 @@ def do_recdownload(packages):
     command = "apt-get --download-only --reinstall -u install " + perform.concat(packageNames)
     perform.execute(command, root=1)
 
+
+def versions(packages):
+    if len(packages) == 0:
+        command = "apt-show-versions"
+    else:
+        command = ""
+    for p in packages:
+        command += "apt-show-versions " + p + "; "
+    perform.execute(command)
+    
+
 def main():
     do_size([], 100)
 
