@@ -65,6 +65,7 @@ def usage():
         -q|--quiet	Do not show progress of commands.
         -s|--simulate   Show commands to be executed but don't execute.
         -t|--teaching   Show commands to be executed and then execute them.
+        -y|--yes        Assume yes for any questions asked.
 """
 
 #
@@ -86,6 +87,7 @@ def help(verbose):
  install        Install (or upgrade) one or more packages or .deb files
  remove         Remove one or more packages (see also purge)
 
+ toupgrade      List packages with newer versions available for upgrading
  upgrade        Upgrade all of the installed packages or just those listed
 
  listfiles      List the files that are supplied by the named package
@@ -213,7 +215,10 @@ Run LIST-COMMANDS for a complete list of commands.
  unofficial     Search for an unofficial Debian package at apt-get.org
  update         Update the list of down-loadable packages
  update-alts    Update default alternative for things like x-window-manager
+ update-pci-ids Updates the local list of PCI ids from the internet master list
+ update-usb-ids Updates the local list of USB ids from the internet master list
  upgrade        Upgrade all of the installed packages or just those listed
+ versions       List version and distribution of (all) packages.
  whatis         A synonym for describe
  whichpkg       Find the package that supplies the given command or file 
 
@@ -224,6 +229,7 @@ Command line options:
  -s|--simulate  Trace but don't execute the sequence of underlying commands.
  -t|--teaching  Trace the sequence of commands performed.
  -v|--verbose=n Increase (or set) the level of verbosity (to n).
+ -y|--yes       Assume yes for any questions asked.
 
 Fuller documentation can be found at http://www.togaware.com/wajig.
 """
@@ -493,6 +499,7 @@ All wajig commands:
  update         Update the list of down-loadable packages
  update-alts    Update default alternative for things like x-window-manager
  upgrade        Upgrade all of the installed packages or just those listed
+ versions       List version and distribution of (all) packages.
  whatis         A synonym for describe
  whichpkg       Find the package that supplies the given command or file 
 
@@ -503,6 +510,7 @@ Command line options:
  -s|--simulate  Trace but don't execute the sequence of underlying commands. 
  -t|--teaching  Trace the sequence of commands performed. 
  -v|--verbose=n Increase (or set) the level of verbosity (to n). 
+ -y|--yes       Assume yes for any questions asked.
 
 Wajig expects a command and will call upon other Debian tools to
 perform the command.  Commands can be in mixed case and with hyphens
@@ -574,10 +582,23 @@ available on it using:
 
   $ wajig add-cd-rom  
 
+
+
 If you want to check when you last did an update then:
 
   $ wajig last-update
 
+There are quite a few archives available and you can test for a good
+connection to one with:
+
+  $ wajig netselect-apt
+
+This will write a candidate sources.list in the current directory,
+which you can then review and add to the system sources.list, if you
+wish, with
+
+  $ wajig edit-sources
+  
 
 FINDING PACKAGES
 
