@@ -189,6 +189,7 @@ def interactive_shell():
 
 def main():
     global pause
+    global yes
     #
     # Remove commas and insert the arguments appropriately.
     #
@@ -205,9 +206,9 @@ def main():
         #
         # Parse the command line arguments
         #
-        sopts = "dhpqstv"
+        sopts = "dhpqstvy"
         lopts = ["debug", "help", "pause", "quiet","simulate","teaching",
-                 "verbose=", "version"]
+                 "verbose=", "version", "yes"]
         opts, args = getopt.getopt(sys.argv[1:], sopts, lopts)
     except getopt.error, e:
         #
@@ -223,6 +224,7 @@ def main():
     teaching = 0
     verbose  = 0
     debug = False
+    yes = "" 
     #
     # Action the command line options
     #
@@ -243,6 +245,8 @@ def main():
         elif o in ("-t", "--teaching"):
             teaching = teaching + 1
             perform.set_teaching_level(teaching)
+        elif o in ("-y", "--yes"):
+            yes = " --yes "
         elif o == "-v":
             verbose = verbose + 1 
             commands.set_verbosity_level(verbose)
@@ -354,10 +358,11 @@ def select_command(command, args, verbose, teaching):
         if requires_args(command, args, "a list of package names"):
             if requires_package("fakeroot", "/usr/bin/fakeroot"):
                 # First make sure dependencies are met
-                perform.execute("apt-get build-dep " +
-                                perform.concat(args[1:]), root=1)
-                perform.execute("fakeroot " + "apt-get source -b " +
-                                perform.concat(args[1:]))
+                result = perform.execute("apt-get build-dep " +
+                                         perform.concat(args[1:]), root=1)
+                if not result:
+                    perform.execute("fakeroot " + "apt-get source -b " +
+                                    perform.concat(args[1:]))
 
     elif command == "builddepend":
         if requires_args(command, args, "a list of package names"):
@@ -408,7 +413,7 @@ def select_command(command, args, verbose, teaching):
     elif command == "distupgrade":
         if requires_opt_arg(command, args,
                             "the distribution to upgrade to"):
-            cmd = "apt-get -u "
+            cmd = "apt-get -u %s " % yes
             if len(args) == 2:
                 cmd += "-t " + args[1] + " "
             cmd += "dist-upgrade"
@@ -765,7 +770,8 @@ def select_command(command, args, verbose, teaching):
 
     elif command == "remove":
         if requires_args(command, args, "a list of packages"):
-            perform.execute("apt-get remove " + perform.concat(args[1:]), root=1)
+            perform.execute("apt-get %s remove %s" %
+                            (yes, perform.concat(args[1:])), root=1)
 
     elif command == "removedepend":
         if requires_one_arg(command, args, "a single package"):
@@ -836,8 +842,11 @@ def select_command(command, args, verbose, teaching):
     elif command == "source":
         if requires_args(command, args, "a list of package names"):
             # First make sure dependencies are met
-            perform.execute("apt-get build-dep " + perform.concat(args[1:]),
-                            root=1)
+            # John V. Belmonte 04 Nov 2005 requested this not be done
+            # Leave it to the user to do wajig builddepend
+            # It is not always necessary
+            #perform.execute("apt-get build-dep " + perform.concat(args[1:]),
+            #                root=1)
             perform.execute("apt-get source " + perform.concat(args[1:]))
 
     elif command == "start":
@@ -898,6 +907,16 @@ def select_command(command, args, verbose, teaching):
         if requires_one_arg(command, args, "name of alternative to update"):
             perform.execute("update-alternatives --config " + args[1], root=1)
 
+    elif command == "updatepciids":
+        if requires_package("pciutils", "/usr/bin/update-pciids"):
+            if requires_no_args(command, args):
+                perform.execute("update-pciids", root=1)
+        
+    elif command == "updateusbids":
+        if requires_package("usbutils", "/usr/sbin/update-usbids"):
+            if requires_no_args(command, args):
+                perform.execute("update-usbids", root=1)
+        
     elif command == "upgrade":
         if len(args) > 1:
             perform.execute("apt-get install " + perform.concat(args[1:]),
@@ -920,9 +939,13 @@ def select_command(command, args, verbose, teaching):
         perform.execute(command, root=1)
         if os.path.exists(sources_list): os.remove(sources_list)
 
-    elif command == "version":
-        documentation.version()
-
+    elif command == "version" or command == "versions":
+        if command == "version" and len(args) == 1:
+            documentation.version()
+        else:
+            if requires_package("apt-show-versions",
+                                "/usr/bin/apt-show-versions"):
+                commands.versions(args[1:])
     elif command == "whatis":
         if requires_args(command, args, "a list of package names"):
             commands.do_describe(args[1:])
